ParaDime
--------

.. automodule:: paradime.paradime
   :members:

Relations
---------

.. automodule:: paradime.relations
   :members:

Relation Data
-------------

.. automodule:: paradime.relationdata
   :members:

Transforms
----------

.. automodule:: paradime.transforms
   :members:

Loss
----

.. automodule:: paradime.loss
   :members:

Routines
--------

.. automodule:: paradime.routines
   :members:
